package WordList::CryptoCurrency::Catalog::Symbol;

our $DATE = '2018-01-16'; # DATE
our $VERSION = '20180116'; # VERSION

use WordList;
our @ISA = qw(WordList);

our %STATS = ("longest_word_len",13,"avg_word_len",3.60413793103448,"shortest_word_len",1,"num_words",1450,"num_words_contains_whitespace",0,"num_words_contains_nonword_chars",2,"num_words_contains_unicode",0); # STATS

1;
# ABSTRACT: List of cryptocurrency symbols

=pod

=encoding UTF-8

=head1 NAME

WordList::CryptoCurrency::Catalog::Symbol - List of cryptocurrency symbols

=head1 VERSION

This document describes version 20180116 of WordList::CryptoCurrency::Catalog::Symbol (from Perl distribution WordLists-CryptoCurrency-Catalog), released on 2018-01-16.

=head1 SYNOPSIS

 use WordList::CryptoCurrency::Catalog::Symbol;

 my $wl = WordList::CryptoCurrency::Catalog::Symbol->new;

 # Pick a (or several) random word(s) from the list
 my $word = $wl->pick;
 my @words = $wl->pick(3);

 # Check if a word exists in the list
 if ($wl->word_exists('foo')) { ... }

 # Call a callback for each word
 $wl->each_word(sub { my $word = shift; ... });

 # Get all the words
 my @all_words = $wl->all_words;

=head1 STATISTICS

 +----------------------------------+------------------+
 | key                              | value            |
 +----------------------------------+------------------+
 | avg_word_len                     | 3.60413793103448 |
 | longest_word_len                 | 13               |
 | num_words                        | 1450             |
 | num_words_contains_nonword_chars | 2                |
 | num_words_contains_unicode       | 0                |
 | num_words_contains_whitespace    | 0                |
 | shortest_word_len                | 1                |
 +----------------------------------+------------------+

The statistics is available in the C<%STATS> package variable.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/WordLists-CryptoCurrency-Catalog>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-WordLists-CryptoCurrency-Catalog>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=WordLists-CryptoCurrency-Catalog>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

__DATA__
$$$
10MT
1337
1ST
2GIVE
300
42
611
808
888
8BIT
9COIN
ABC
ABJ
ABN
ABY
AC
ACC
ACE
ACES
ACN
ACOIN
ACP
ACT
ADA
ADC
ADCN
ADCOIN
ADK
ADL
ADST
ADT
ADX
ADZ
AE
AEON
AERM
AGLC
AGRS
AHT
AI
AIB
AIDOC
AION
AIR
AIT
AIX
AKY
ALIS
ALL
ALQO
ALT
ALTC
ALTCOM
AMB
AMBER
AMM
AMMO
AMP
AMS
ANC
ANI
ANT
ANTI
ANTX
APC
APPC
APW
APX
ARB
ARC
ARCADE
ARCO
ARDR
ARG
ARGUS
ARI
ARK
ARN
ART
ASAFE2
ASN
AST
ASTRO
ATB
ATL
ATM
ATMC
ATMS
ATN
ATOM
ATS
ATX
AU
AUR
AV
AVT
AWR
AXIOM
B2B
B2X
B3
B@
BAC
BAS
BASH
BAT
BATCOIN
BAY
BBP
BBR
BBT
BCA
BCAP
BCC
BCD
BCDN
BCF
BCH
BCN
BCO
BCPT
BCX
BCY
BDG
BDL
BELA
BENJI
BERN
BEST
BET
BETACOIN
BIG
BIGUP
BIOB
BIOS
BIP
BIRDS
BIS
BIT
BITB
BITBTC
BITCF
BITCLAVE
BITCNY
BITEUR
BITGEM
BITGOLD
BITMARK
BITOK
BITS
BITSILVER
BITUSD
BITZ
BIX
BKX
BLAS
BLAZR
BLC
BLITZ
BLK
BLN
BLOCK
BLOCKPAY
BLRY
BLT
BLU
BLUE
BLX
BLZ
BMC
BNB
BNT
BNTY
BNX
BOAT
BOLI
BON
BOS
BOST
BOT
BPC
BPL
BQ
BRAIN
BRAT
BRD
BRIA
BRIT
BRK
BRO
BRX
BSC
BSD
BSN
BSR
BSTAR
BSTY
BT1
BT2
BTA
BTB
BTBc
BTC
BTC2X
BTCA
BTCD
BTCM
BTCR
BTCRED
BTCS
BTCSILVER
BTCZ
BTDX
BTE
BTG
BTM
BTO
BTPL
BTQ
BTS
BTSR
BTWTY
BTX
BUB
BUCKS
BUMBA
BUN
BURST
BUZZ
BVC
BWK
BXC
BXT
BYC
C2
CAB
CACH
CAG
CALC
CAN
CANETWORK
CANN
CAPP
CARBON
CASH
CASHPOKERPRO
CASINO
CAT
CATCOIN
CBD
CBX
CC
CCM100
CCN
CCO
CCRB
CCT
CDN
CDT
CDX
CEFS
CESC
CF
CFC
CFD
CFI
CFT
CFUN
CHAN
CHC
CHEAP
CHESS
CHIPS
CJ
CL
CLAM
CLD
CLOAK
CLUB
CME
CMP
CMPCO
CMSETH
CMSXEM
CMT
CND
CNNC
CNO
CNT
CNX
COAL
COB
COLX
COMET
CON
CONX
COR
CORG
COSS
COUPE
COVAL
COXST
CPAY
CPC
CPN
CRAVE
CRB
CRC
CRDNC
CREA
CRED
CREDO
CREVA
CRM
CRT
CRTM
CRW
CRX
CRYPT
CSNO
CTIC2
CTIC3
CTO
CTR
CTX
CUBE
CUBIT
CURE
CV2
CVC
CVCOIN
CWXT
CXT
CYC
CYDER
CYP
DAI
DALC
DAR
DASH
DASHS
DAT
DATA
DAV
DAXX
DAY
DBC
DBET
DBG
DBIX
DBTC
DCN
DCR
DCRE
DCT
DCY
DDF
DEM
DENT
DES
DEUS
DEW
DFS
DFT
DGB
DGC
DGCS
DGD
DGPT
DIBC
DICE
DIM
DIME
DISK
DIVX
DIX
DLC
DLISK
DLT
DMB
DMC
DMD
DNA
DNR
DNT
DOGE
DOLLAR
DON
DOPE
DOT
DOVU
DP
DPY
DRGN
DRM
DRP
DRS
DRT
DRXNE
DSH
DSR
DTB
DTR
DUB
DUO
DUTCH
DYN
E4ROW
EAC
EAG
EAGLE
EBCH
EBET
EBIT
EBST
EBT
EBTC
ECA
ECASH
ECC
ECN
ECO
ECOB
EDG
EDO
EDR
EDRC
EDT
EFL
EFYT
EGAS
EGC
EGG
EGO
EGOLD
EKO
EL
ELC
ELE
ELF
ELITE
ELIX
ELLA
ELS
ELTC2
ELTCOIN
EMC
EMC2
EMD
EMV
ENG
ENJ
ENRG
ENT
ENTCASH
EOS
EOT
EPY
EQT
ERC
ERC20
EREAL
ERO
ERY
ESC
ESP
ETBS
ETC
ETG
ETH
ETHD
ETHOS
ETN
ETP
ETTETH
ETTWAVES
EUC
EUSD
EVC
EVIL
EVO
EVR
EVX
EXCL
EXN
EXP
EXRN
FAIR
FAIRGAME
FAP
FAZZ
FBL
FC
FC2
FCN
FCT
FDX
FFC
FID
FIL
FIMK
FIRE
FJC
FLAP
FLASH
FLAX
FLDC
FLIK
FLIXX
FLO
FLT
FLVR
FLY
FNC
FONZ
FOR
FRAZ
FRC
FRCT
FRD
FRGC
FRK
FRN
FRST
FRWC
FST
FTC
FUCK
FUDD
FUEL
FUN
FUNC
FUNK
FUTC
FUZZ
FXE
FYN
FYP
G3N
GAIA
GAIN
GAM
GAME
GAME2
GAP
GARY
GAS
GAY
GB
GBC
GBG
GBRC
GBT
GBX
GBYTE
GCC
GCN
GCR
GCS
GEERT
GEO
GET
GIM
GJC
GLC
GLD
GLS
GLT
GML
GMT
GMX
GNO
GNT
GNX
GOD
GOLF
GOLOS
GOOD
GP
GPL
GPU
GRC
GRE
GRID
GRIM
GRN
GRS
GRT
GRWI
GRX
GSR
GTC
GTO
GUC
GUCCIONE
GUN
GUP
GVT
GXS
HAC
HAL
HALLO
HAT
HBC
HBN
HBT
HCC
HDG
HDLB
HEAT
HERO
HGT
HIGH
HKN
HMC
HMP
HMQ
HNC
HODL
HOLD
HONEY
HPB
HPC
HPY
HSR
HST
HTC
HTML
HTML5
HUC
HUNCOIN
HUSH
HVCO
HVN
HWC
HXX
HYP
HYPER
HYTV
I0C
IBANK
IBTC
IC
ICE
ICN
ICOB
ICOIN
ICON
ICOO
ICOS
ICX
IDT
IETH
IFC
IFLT
IFT
IGNIS
IMPS
IMS
IMX
INCNT
IND
INDIA
INF
INFX
INK
INN
INPAY
INS
INSN
INT
INTLDIAMOND
INXT
IOC
ION
IOP
IOST
IPY
IQT
IRL
ISL
ITC
ITI
ITNS
ITT
ITZ
IVZ
IXC
IXT
J
JET
JIN
JINN
JNS
JOBS
JS
JWL
KARMA
KASHH
KAYI
KBR
KCASH
KCS
KED
KEK
KEY
KICK
KIN
KINGN
KLC
KLN
KMC
KMD
KNC
KOBO
KORE
KRB
KRM
KRONE
KURT
KUSH
KZC
LA
LANA
LAZ
LBC
LBTC
LCP
LCT
LDCN
LDOGE
LEA
LEEK
LEND
LEO
LEPEN
LEV
LEX
LGD
LIFE
LIGHTNINGBTC
LINDA
LINK
LINX
LIR
LKC
LKK
LLT
LMC
LNK
LOC
LOG
LOT
LRC
LSK
LTB
LTC
LTCR
LTCU
LTG
LTH
LUN
LUNA
LUX
LVPS
MAC
MAD
MAG
MAGE
MAGN
MAID
MANA
MAO
MAR
MARS
MARX
MAVRO
MAX
MAY
MBI
MBL
MBRS
MCAP
MCI
MCO
MCR
MCRN
MDA
MDC
MDS
MDT
MEC
MED
MEME
MEN
MER
METAL
MGC
MGM
MGO
MILO
MINEX
MINT
MIOTA
MIXIN
MKR
MLN
MMXVI
MNC
MND
MNE
MNM
MNX
MOAC
MOD
MOIN
MOJO
MONA
MONETA
MONEY
MONK
MOON
MOT
MOTO
MRJA
MRNG
MRT
MSCN
MSD
MSP
MST
MTH
MTL
MTLMC3
MTM
MTNC
MTX
MUE
MUSIC
MUT
MXT
MYB
MYST
MZC
NAMO
NANOX
NAS
NAV
NBIT
NDC
NEBL
NEO
NEOG
NEOS
NET
NETCOIN
NETKO
NEU
NEVA
NEWB
NGC
NIMFA
NIO
NKA
NLC2
NLG
NMC
NMR
NMS
NOBL
NODC
NOTE
NRO
NSR
NTC
NTO
NTRN
NTWK
NUKO
NULS
NUMUS
NVC
NVST
NXC
NXS
NXT
NYAN
NYC
OAX
OBITS
OCEAN
OCL
OCOW
OCT
ODN
OFF
OK
OMC
OMG
OMNI
ONG
ONION
ONX
OP
OPAL
OPC
OPES
OPT
ORB
ORLY
ORME
OS76
OST
OTN
OTX
OX
OXY
P7C
PAC
PAK
PART
PASC
PASL
PAY
PAYP
PAYX
PBL
PBT
PCN
PCOIN
PCS
PDC
PDG
PEC
PEPECASH
PEX
PFR
PGL
PHO
PHR
PHS
PIE
PIGGY
PING
PINK
PIPL
PIRL
PIVX
PIX
PIZZA
PKB
PKT
PLACO
PLAY
PLBT
PLC
PLNC
PLR
PLU
PLX
PND
PNX
POE
POKE
POLIS
POLL
PONZI
POP
POS
POST
POSW
POT
POWR
PPC
PPP
PPT
PPY
PR
PRC
PRES
PRG
PRIMU
PRIX
PRL
PRM
PRN
PRO
PROCHAIN
PROCURRENCY
PRS
PRX
PST
PSY
PTC
PTOY
PULSE
PURA
PURE
PUT
PX
PXC
PXI
PYLNT
PZM
Q2C
QASH
QAU
QBC
QBK
QBT
QCN
QLC
QORA
QRK
QRL
QSP
QTL
QTUM
QUBE
QUN
QVT
QWARK
R
RADS
RAIN
RBBT
RBIES
RBT
RBX
RBY
RC
RCN
RCOIN
RDD
RDN
REAL
REBL
REC
RED
REE
REGA
REMI
REP
REQ
REX
RHFC
RHOC
RIC
RICHX
RIDE
RISE
RIYA
RKC
RLC
RLT
RMC
RNS
RNT
ROC
ROOFS
ROYAL
RPC
RPX
RSGP
RUBIT
RUNNERS
RUP
RUPX
RUPXOLD
RUSTBITS
RVT
RYZ
SAC
SAFEX
SAGA
SAK
SALT
SAN
SANDG
SBC
SBD
SBTC
SC
SCL
SCORE
SCRT
SCS
SCT
SDC
SDP
SDRN
SEND
SEQ
SFC
SFE
SGR
SH
SHA
SHDW
SHELL
SHIFT
SHND
SHORTY
SHOW
SIB
SIC
SIFT
SIGMA
SIGT
SISA
SJCX
SKC
SKIN
SKR
SKULL
SKY
SLEVIN
SLFI
SLG
SLING
SLR
SLS
SMART
SMARTBILLIONS
SMC
SMLY
SMT
SNAKE
SNC
SND
SNGLS
SNM
SNOV
SNRG
SNT
SOAR
SOCC
SOIL
SOJ
SONG
SOON
SPACE
SPANK
SPEX
SPF
SPHR
SPHTX
SPORT
SPR
SPRTS
SPT
SRC
SRN
SSS
STA
STAK
STAR
STARS
START
STC
STEEM
STEPS
STEX
STN
STORJ
STORM
STRAT
STRC
STS
STU
STV
STX
SUB
SUMO
SUPER
SUR
SWFTC
SWIFT
SWING
SWP
SWT
SWTC
SXC
SXDT
SXUT
SYNX
SYS
TAAS
TAG
TAGR
TAJ
TALK
TAU
TCC
TCOIN
TCR
TCT
TEAM
TEK
TEL
TELL
TER
TERA
TES
TESLA
TFL
TGC
TGT
THC
THS
TIE
TIME
TIO
TIPS
TIT
TIX
TKN
TKR
TKS
TLE
TNB
TNT
TOA
TODAY
TOK
TOKC
TOKEN
TOP
TOPAZ
TOPC
TOR
TRC
TRCT
TRDT
TRI
TRIA
TRICK
TRIG
TRK
TROLL
TRST
TRUMP
TRUST
TRX
TSE
TSL
TSTR
TTC
TURBO
TX
TYCHO
TZC
UAHPAY
UBQ
UBTC
UET
UFO
UFR
UGC
UGT
UIS
UKG
ULA
UNB
UNC
UNI
UNIC
UNIFY
UNIT
UNITS
UNITY
UNO
UNRC
UNY
UQC
UR
URC
URO
USC
USDE
USDT
USNBT
UTA
UTC
UTK
UTT
V
VAL
VASH
VC
VEC2
VEE
VEN
VERI
VIA
VIB
VIBE
VIDZ
VIP
VISIO
VIU
VIVO
VLT
VLTC
VOISE
VOLT
VOT
VOX
VOYA
VPRC
VRC
VRM
VRS
VSL
VSX
VTA
VTC
VTR
VUC
VULC
VZT
WA
WABI
WAND
WARP
WAVES
WAX
WAY
WAYKI
WBB
WC
WCT
WDC
WETH
WGO
WGR
WHL
WIC
WILD
WINGS
WINK
WISH
WMC
WOMEN
WORM
WOW
WRC
WSX
WTC
WTT
X2
XAS
XAU
XAUR
XBC
XBL
XBTC21
XBTS
XBY
XCN
XCO
XCP
XCPO
XCRE
XCS
XCT
XCXT
XDE2
XDN
XEL
XEM
XFT
XGOX
XGR
XHI
XID
XIN
XIOS
XJO
XLC
XLM
XLR
XMCC
XMG
XMR
XMY
XNG
XNN
XOC
XOT
XP
XPA
XPD
XPM
XPTX
XPY
XQN
XRA
XRB
XRC
XRE
XRL
XRP
XRY
XSH
XSPEC
XST
XSTC
XTD
XTO
XTZ
XUC
XVC
XVE
XVG
XVP
XWC
XYLO
XZC
YAC
YASH
YEL
YES
YOC
YOYOW
YTN
ZAP
ZBC
ZCG
ZCL
ZEC
ZEIT
ZEN
ZENGOLD
ZENI
ZEPH
ZER
ZET
ZMC
ZNE
ZNY
ZOI
ZRC
ZRX
ZSC
ZSE
ZUR
ZYD
ZZC
